# Generated by Django 3.2.12 on 2022-03-31 11:10

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("fcm_django", "0008_auto_20211224_1205"),
    ]

    operations = [
        migrations.AlterField(
            model_name="fcmdevice",
            name="user",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_query_name="fcmdevice",
                to=settings.AUTH_USER_MODEL,
            ),
        ),
    ]
